[gimp] Show maintainers after creators in About-dialog
- From: Martin Nordholts <martinn src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] Show maintainers after creators in About-dialog
- Date: Thu, 27 Jan 2011 20:23:09 +0000 (UTC)
commit ab5bd03a9c47a275ab2d3b7e47aafdcb9a89ea0d
Author: Martin Nordholts <martinn src gnome org>
Date: Thu Jan 27 18:48:30 2011 +0100
Show maintainers after creators in About-dialog
It makes sense to show maintainers after creators in the About-dialog,
do that.
app/dialogs/about-dialog.c | 7 +++++--
app/dialogs/authors.xsl | 12 ++++++++++++
authors.xml | 5 +++--
3 files changed, 20 insertions(+), 4 deletions(-)
---
diff --git a/app/dialogs/authors.xsl b/app/dialogs/authors.xsl
index d06317c..1fa301b 100644
--- a/app/dialogs/authors.xsl
+++ b/app/dialogs/authors.xsl
@@ -26,10 +26,20 @@ static const gchar * const creators[] =
</xsl:text>
<xsl:text>
+static const gchar * const maintainers[] =
+{
+</xsl:text>
+ <xsl:apply-templates select="dc:maintainer" />
+<xsl:text> NULL
+};
+</xsl:text>
+
+<xsl:text>
static const gchar * const authors[] =
{
</xsl:text>
<xsl:apply-templates select="dc:creator" />
+ <xsl:apply-templates select="dc:maintainer" />
<xsl:call-template name="recent-contributor">
<xsl:with-param name="role" select="'author'"/>
</xsl:call-template>
@@ -62,6 +72,8 @@ static const gchar * const documenters[] =
<xsl:template match="dc:creator"> "<xsl:apply-templates />",
</xsl:template>
+ <xsl:template match="dc:maintainer"> "<xsl:apply-templates />",
+</xsl:template>
<xsl:template match="dc:contributor"> "<xsl:apply-templates />",
</xsl:template>
diff --git a/authors.xml b/authors.xml
index ad0dda1..6a05a39 100644
--- a/authors.xml
+++ b/authors.xml
@@ -11,6 +11,9 @@
<creator role="author" last-active="2.2">Spencer Kimball</creator>
<creator role="author" last-active="1.0">Peter Mattis</creator>
+ <maintainer role="author" last-active="2.8">Sven Neumann</maintainer>
+ <maintainer role="author" last-active="2.8">Michael Natterer</maintainer>
+
<contributor role="author" last-active="1.2">Lauri Alanko</contributor>
<contributor role="author" last-active="2.8">Fredrik Alströmer</contributor>
<contributor role="author" last-active="1.2">Shawn Amundson</contributor>
@@ -187,10 +190,8 @@
<contributor role="author" last-active="1.2">Yukihiro Nakai</contributor>
<contributor role="author" last-active="1.2">Shuji Narazaki</contributor>
<contributor role="author" last-active="1.2">Felix Natter</contributor>
- <contributor role="author" last-active="2.8">Michael Natterer</contributor>
<contributor role="author" last-active="2.4">David Neary</contributor>
<contributor role="author" last-active="2.2">David Necas</contributor>
- <contributor role="author" last-active="2.8">Sven Neumann</contributor>
<contributor role="author" last-active="2.8">Andreas Neustifter</contributor>
<contributor role="artist" last-active="2.4">Andreas Nilsson</contributor>
<contributor role="author" last-active="1.0">Stephen Robert Norris</contributor>
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/app/dialogs/about-dialog.c b/app/dialogs/about-dialog.c
index bda27cd..e947dda 100644
--- a/app/dialogs/about-dialog.c
+++ b/app/dialogs/about-dialog.c
@@ -41,8 +41,11 @@
#include "gimp-intl.h"
-/* The first authors are the creators, don't shuffle them */
-#define START_INDEX (G_N_ELEMENTS (creators) - 1 /*NULL*/)
+/* The first authors are the creators and maintainers, don't shuffle
+ * them
+ */
+#define START_INDEX (G_N_ELEMENTS (creators) - 1 /*NULL*/ + \
+ G_N_ELEMENTS (maintainers) - 1 /*NULL*/)
typedef struct